Enum googapis::google::cloud::asset::v1::partition_spec::PartitionKey [−][src]
#[repr(i32)]
pub enum PartitionKey {
Unspecified,
ReadTime,
RequestTime,
}Expand description
This enum is used to determine the partition key column when exporting assets to BigQuery partitioned table(s). Note that, if the partition key is a timestamp column, the actual partition is based on its date value (expressed in UTC. see details in https://cloud.google.com/bigquery/docs/partitioned-tables#date_timestamp_partitioned_tables).
Variants
Unspecified partition key. If used, it means using non-partitioned table.
The time when the snapshot is taken. If specified as partition key, the result table(s) is partitoned by the additional timestamp column, readTime. If [read_time] in ExportAssetsRequest is specified, the readTime column’s value will be the same as it. Otherwise, its value will be the current time that is used to take the snapshot.
The time when the request is received and started to be processed. If specified as partition key, the result table(s) is partitoned by the requestTime column, an additional timestamp column representing when the request was received.
Implementations